# Project1
## Outline
This project aims to predict stock prices through the following methods

Sentiment analysis:
- Sentiment on news headlines
- Sentiment on tweets from twitter
- Sentiment on Reddit feeds

Stock prices:
- Use stock historic data to evaluate current stock prices
- Calculate the risk of a stock (how volatile a stock is)

Machine learning:
- Use machine learning techniques to further predict stock prices

## TO USE
Please add the required parameters of your pgAdmin 4 data base to the config.py file before runnning
